@@ -2,7 +2,7 @@ package CGI::ExceptionManager;
 use strict;
 use warnings;
 use 5.00800;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub detach { die bless [], 'CGI::ExceptionManager::Exception' }
 
@@ -23,7 +23,7 @@ sub run {
             }
             $err_info = CGI::ExceptionManager::StackTrace->new($msg);
         }
-        die;
+        die $msg;
     };
     local $@;
     eval {
